<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'Интегрировать TextWheel в SPIP',
	'tw_slogan' => 'Управлять оформлением SPIP c помощью TextWheel',
];
